#include "easynirwrapper.h"

#define DEVICE_INDEX 0

int     fileSize = 0;       //数据长度
double *pWavelengths;       //用于存储波长
int    *pIntensities;       //用于存储光谱强度

void connectDevice()
{
    int num = 0;    //获取设备连接数
    int res = enumerateDevices(&num);   //接口返回值

    if(res<0)
        printf("Connect device failed: %d\n", res);
    else
        printf("Connect device succeeded: %d\n", num);
}

void openDevice()
{
    int res;    //接口返回值

    closeSpectrometer();    //先关闭光谱仪

    res = openSpectrometer(DEVICE_INDEX);     //打开光谱仪
    if(res<0)
        printf("Open device failed: %d\n", res);
    else
        printf("Open device succeeded: %d\n", res);
}

void getSpectrumLength()
{
    int res = getFormattedSpectrumLengths(&fileSize); //获取光谱数据长度
    if(res<0)
        printf("Get fileSize failed: %d\n", res);
    else
        printf("Get fileSize succeeded: %d\n", fileSize);

    pWavelengths = (double*)malloc(fileSize*sizeof(double));    //申请波长内存空间
    pIntensities = (int*)malloc(fileSize*sizeof(int));          //申请光谱强度内存空间
}

void setPgaGain()
{
    unsigned char pga = 32;       //增益倍率为32

    int res = setPGAGain(1, pga); //设置成固定模式
    if(res<0)
        printf("Set PGA failed: %d\n", res);
    else
        printf("Set PGA succeeded: %d\n", res);
}

void setAvgTimes()
{
    int avg = 6;    //定义平均次数并赋值6
    int res = setSpectrumAverageTime(avg);  //设置平均次数
    if(res<0)
        printf("Set avg failed: %d\n", res);
    else
        printf("Set avg succeeded: %d\n", res);
}

void getSpectrumData()
{
    int dataSize = 0;    //获取输出数据数量

    int res = getFormattedSpectrum(pWavelengths,pIntensities,&dataSize);    //获取光谱数据

    if(res<0)
        printf("Get spectrum data failed: %d\n", res);
    else
        printf("Get spectrum data succeeded: %d\n", res);

    //打印波长值和对应的光谱强度值
    for (int i=0;i<dataSize;i++)
        printf("Wavelength: %f, Intensity: %d\n", pWavelengths[i], pIntensities[i]);
}

void setLampStatus()
{
    int res = setLampStatus(0); //设置内置光源为关闭状态

    if(res<0)
        printf("Set lamp failed: %d\n", res);
    else
        printf("Set lamp succeeded: %d\n", res);
}

int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);

    connectDevice();
    openDevice();
    getSpectrumLength();
    setPgaGain();
    setAvgTimes();
    setLampStatus();
    getSpectrumData();

    return a.exec();
}
